summaryrefslogtreecommitdiffstats
path: root/ksirc/kstextview.h
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-15 15:49:40 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-15 15:49:40 -0600
commit808e453c56036211f57482ed847d54aca01bba68 (patch)
tree75515d5768dea10d4fbe4cd772e0a89c1c4b3aa9 /ksirc/kstextview.h
parentcd9b9ed7fd0ac8a75106148254aa58e2e5c04863 (diff)
downloadtdenetwork-808e453c56036211f57482ed847d54aca01bba68.tar.gz
tdenetwork-808e453c56036211f57482ed847d54aca01bba68.zip
Rename a number of old tq methods that are no longer tq specific
Diffstat (limited to 'ksirc/kstextview.h')
-rw-r--r--ksirc/kstextview.h24
1 files changed, 12 insertions, 12 deletions
diff --git a/ksirc/kstextview.h b/ksirc/kstextview.h
index 6b3813a8..1c537e95 100644
--- a/ksirc/kstextview.h
+++ b/ksirc/kstextview.h
@@ -40,7 +40,7 @@ struct StringPtr
StringPtr( const TQChar *_ptr, uint _len )
: ptr( _ptr ), len( _len ) {}
explicit StringPtr( const TQString &s ) // use with care!
- : ptr( s.tqunicode() ), len( s.length() ) {}
+ : ptr( s.unicode() ), len( s.length() ) {}
inline bool isNull() const { return ptr == 0; }
@@ -142,8 +142,8 @@ class SelectionPoint;
class Item
{
public:
- enum LayoutResettqStatus { DeleteItem, KeepItem };
- enum SelectiontqStatus { SelectionStart = 0, InSelection, SelectionEnd, SelectionBoth,
+ enum LayoutResetStatus { DeleteItem, KeepItem };
+ enum SelectionStatus { SelectionStart = 0, InSelection, SelectionEnd, SelectionBoth,
NoSelection };
enum SelectionAccuracy { SelectExact, SelectFuzzy };
@@ -163,13 +163,13 @@ public:
virtual Item *breakLine( int width );
- virtual LayoutResettqStatus resetLayout() = 0;
+ virtual LayoutResetStatus resetLayout() = 0;
virtual int calcSelectionOffset( int x );
- void setSelectiontqStatus( SelectiontqStatus status ) { m_selection = status; }
+ void setSelectionStatus( SelectionStatus status ) { m_selection = status; }
- SelectiontqStatus selectiontqStatus() const { return m_selection; }
+ SelectionStatus selectionStatus() const { return m_selection; }
void selectionOffsets( int &startOffset, int &endOffset );
@@ -194,7 +194,7 @@ protected:
virtual void calcExtends() const = 0;
- SelectiontqStatus m_selection;
+ SelectionStatus m_selection;
TextLine *m_line;
TextParag *m_parag;
ItemProperties m_props;
@@ -211,7 +211,7 @@ public:
virtual Item *breakLine( int width );
- virtual LayoutResettqStatus resetLayout();
+ virtual LayoutResetStatus resetLayout();
virtual int calcSelectionOffset( int x );
@@ -247,7 +247,7 @@ public:
virtual void paint( TQPainter &painter );
- virtual LayoutResettqStatus resetLayout();
+ virtual LayoutResetStatus resetLayout();
protected:
virtual void calcExtends() const;
@@ -354,7 +354,7 @@ public:
~TextParag();
- void tqlayout( int width );
+ void layout( int width );
void paint( TQPainter &p, int y, int maxY );
@@ -482,7 +482,7 @@ public:
bool removeParag( const TextParagIterator &parag );
- void clearSelection( bool tqrepaint = false ); // ### re-consider the tqrepaint arg...
+ void clearSelection( bool repaint = false ); // ### re-consider the repaint arg...
TQString selectedText() const { return m_selectedText; }
@@ -537,7 +537,7 @@ private:
SelectionPoint *selectionStart();
SelectionPoint *selectionEnd();
- void tqlayout( bool force = true );
+ void layout( bool force = true );
Item *itemAt( const TQPoint &pos, SelectionPoint *selectionInfo = 0,
Item::SelectionAccuracy accuracy = Item::SelectExact );